@@ -18,8 +18,6 @@ from typing import (
     Union,
 )
 
-from async_timeout import timeout as atimeout
-
 from aioredis_cluster.abc import AbcChannel, AbcCluster, AbcPool
 from aioredis_cluster.aioredis import Redis, create_pool
 from aioredis_cluster.aioredis.errors import (
@@ -30,7 +28,8 @@ from aioredis_cluster.aioredis.errors import (
 from aioredis_cluster.command_exec import ExecuteContext, ExecuteFailProps, ExecuteProps
 from aioredis_cluster.command_info import CommandInfo, extract_keys
 from aioredis_cluster.commands import RedisCluster
-from aioredis_cluster.crc import key_slot
+from aioredis_cluster.compat.asyncio import timeout as atimeout
+from aioredis_cluster.crc import CrossSlotError, determine_slot
 from aioredis_cluster.errors import (
     AskError,
     ClusterClosedError,
@@ -363,7 +362,10 @@ class Cluster(AbcCluster):
         Can be tested as bool indicating Pub/Sub mode state.
         """
 
-        return sum(p.in_pubsub for p in self._pooler.pools())
+        for pool in self._pooler.pools():
+            if pool.in_pubsub:
+                return 1
+        return 0
 
     @property
     def pubsub_channels(self) -> Mapping[str, AbcChannel]:
@@ -419,12 +421,10 @@ class Cluster(AbcCluster):
         await self._pooler.batch_op(authorize)
 
     def determine_slot(self, first_key: bytes, *keys: bytes) -> int:
-        slot: int = key_slot(first_key)
-        for k in keys:
-            if slot != key_slot(k):
-                raise RedisClusterError("all keys must map to the same key slot")
-
-        return slot
+        try:
+            return determine_slot(first_key, *keys)
+        except CrossSlotError as e:
+            raise RedisClusterError(str(e)) from None
 
     async def all_masters(self) -> List[Redis]:
         ctx = self._make_exec_context((b"PING",), {})
