@@ -1,7 +1,6 @@
 import asyncio
 import atexit
 import contextlib
-import inspect
 import os
 import socket
 import ssl
@@ -10,13 +9,27 @@ import sys
 import tempfile
 import time
 from collections import namedtuple
+from functools import partial
+from typing import List
 from urllib.parse import urlencode, urlunparse
 
 import pytest
-from async_timeout import timeout as async_timeout
+import pytest_asyncio
 
 from aioredis_cluster import _aioredis as aioredis
 from aioredis_cluster._aioredis import sentinel as aioredis_sentinel
+from aioredis_cluster.aioredis import create_redis as custom_create_redis
+from aioredis_cluster.compat.asyncio import timeout as atimeout
+from aioredis_cluster.connection import RedisConnection
+
+try:
+    import aioredis as _origin_aioredis
+
+    (_origin_aioredis,)
+    aioredis_installed = True
+except ImportError:
+    aioredis_installed = False
+
 
 TCPAddress = namedtuple("TCPAddress", "host port")
 
@@ -27,24 +40,12 @@ SentinelServer = namedtuple("SentinelServer", "name tcp_address unixsocket versi
 # Public fixtures
 
 
-# @pytest.yield_fixture
-# def loop():
-#     """Creates new event loop."""
-#     loop = asyncio.new_event_loop()
-#     if sys.version_info < (3, 8):
-#         asyncio.set_event_loop(loop)
-
-#     try:
-#         yield loop
-#     finally:
-#         if hasattr(loop, "is_closed"):
-#             closed = loop.is_closed()
-#         else:
-#             closed = loop._closed  # XXX
-#         if not closed:
-#             loop.call_soon(loop.stop)
-#             loop.run_forever()
-#             loop.close()
+@pytest.fixture(scope="session")
+def event_loop():
+    policy = asyncio.get_event_loop_policy()
+    loop = policy.new_event_loop()
+    yield loop
+    loop.close()
 
 
 @pytest.fixture(scope="session")
@@ -59,7 +60,7 @@ def unused_port():
     return fun
 
 
-@pytest.fixture
+@pytest_asyncio.fixture
 def create_connection(_closable):
     """Wrapper around aioredis.create_connection."""
 
@@ -71,7 +72,26 @@ def create_connection(_closable):
     return f
 
 
-@pytest.fixture(params=[aioredis.create_redis, aioredis.create_redis_pool], ids=["single", "pool"])
+create_redis_fixture_params: List = [
+    aioredis.create_redis,
+    aioredis.create_redis_pool,
+]
+create_redis_fixture_ids: List = [
+    "single",
+    "pool",
+]
+
+if aioredis_installed is False:
+    create_redis_fixture_params.append(partial(custom_create_redis, connection_cls=RedisConnection))
+    create_redis_fixture_ids.append(
+        "single_from_cluster",
+    )
+
+
+@pytest_asyncio.fixture(
+    params=create_redis_fixture_params,
+    ids=create_redis_fixture_ids,
+)
 def create_redis(_closable, request):
     """Wrapper around aioredis.create_redis."""
     factory = request.param
@@ -84,7 +104,7 @@ def create_redis(_closable, request):
     return f
 
 
-@pytest.fixture
+@pytest_asyncio.fixture
 def create_pool(_closable):
     """Wrapper around aioredis.create_pool."""
 
@@ -96,7 +116,7 @@ def create_pool(_closable):
     return f
 
 
-@pytest.fixture
+@pytest_asyncio.fixture
 def create_sentinel(_closable):
     """Helper instantiating RedisSentinel client."""
 
@@ -110,40 +130,48 @@ def create_sentinel(_closable):
     return f
 
 
-@pytest.fixture
-def pool(create_pool, server, event_loop):
+@pytest_asyncio.fixture
+async def pool(create_pool, server):
     """Returns RedisPool instance."""
-    return event_loop.run_until_complete(create_pool(server.tcp_address))
+    pool = await create_pool(server.tcp_address)
+    return pool
 
 
-@pytest.fixture
-def redis(create_redis, server, event_loop):
+@pytest_asyncio.fixture
+async def redis(create_redis, server, add_async_finalizer):
     """Returns Redis client instance."""
-    redis = event_loop.run_until_complete(create_redis(server.tcp_address))
 
-    async def clear():
-        await redis.flushall()
-
-    event_loop.run_until_complete(clear())
+    redis = await create_redis(server.tcp_address)
+    add_async_finalizer(redis.flushall())
     return redis
 
 
-@pytest.fixture
-def redis_sentinel(create_sentinel, sentinel, event_loop):
+@pytest_asyncio.fixture
+async def redis_sentinel(create_sentinel, sentinel):
     """Returns Redis Sentinel client instance."""
-    redis_sentinel = event_loop.run_until_complete(
-        create_sentinel([sentinel.tcp_address], timeout=2)
-    )
 
-    async def ping():
-        return await redis_sentinel.ping()
-
-    assert event_loop.run_until_complete(ping()) == b"PONG"
+    redis_sentinel = await create_sentinel([sentinel.tcp_address], timeout=2)
+    ping_result = await redis_sentinel.ping()
+    assert ping_result == b"PONG"
     return redis_sentinel
 
 
-@pytest.yield_fixture
-def _closable(event_loop):
+@pytest_asyncio.fixture
+async def add_async_finalizer():
+    finalizers = []
+
+    def adder(finalizer):
+        finalizers.append(finalizer)
+
+    try:
+        yield adder
+    finally:
+        for finalizer in finalizers:
+            await finalizer
+
+
+@pytest_asyncio.fixture
+async def _closable():
     conns = []
 
     async def close():
@@ -158,22 +186,22 @@ def _closable(event_loop):
     try:
         yield conns.append
     finally:
-        event_loop.run_until_complete(close())
+        await close()
 
 
-@pytest.fixture(scope="session")
+@pytest_asyncio.fixture(scope="session")
 def server(start_server):
     """Starts redis-server instance."""
     return start_server("A")
 
 
-@pytest.fixture(scope="session")
+@pytest_asyncio.fixture(scope="session")
 def serverB(start_server):
     """Starts redis-server instance."""
     return start_server("B")
 
 
-@pytest.fixture(scope="session")
+@pytest_asyncio.fixture(scope="session")
 def sentinel(start_sentinel, request, start_server):
     """Starts redis-sentinel instance with one master -- masterA."""
     # Adding master+slave for normal (no failover) tests:
@@ -185,7 +213,7 @@ def sentinel(start_sentinel, request, start_server):
     return start_sentinel("main", masterA, master_no_fail)
 
 
-@pytest.fixture(params=["path", "query"])
+@pytest_asyncio.fixture(params=["path", "query"])
 def server_tcp_url(server, request):
     def make(**kwargs):
         netloc = "{0.host}:{0.port}".format(server.tcp_address)
@@ -262,6 +290,16 @@ def format_version(srv):
     return "redis_v{}".format(".".join(map(str, VERSIONS[srv])))
 
 
+_ready_check_log_entries = [
+    "The server is now ready to accept connections ",
+    "Ready to accept connections tcp",
+]
+_slave_ready_check_log_entries = [
+    "sync: Finished with success",
+    "MASTER <-> REPLICA sync: Finished with success",
+]
+
+
 @pytest.fixture(scope="session")
 def start_server(_proc, request, unused_port, server_bin):
     """Starts Redis server instance.
@@ -308,6 +346,8 @@ def start_server(_proc, request, unused_port, server_bin):
                 write("dir ", data_dir)
                 write("dbfilename", dumpfile)
                 write("port", port)
+                if version >= (7, 2):
+                    write("locale-collate", '"C"')
                 if unixsocket:
                     write("unixsocket", unixsocket)
                     tmp_files.append(unixsocket)
@@ -342,6 +382,12 @@ def start_server(_proc, request, unused_port, server_bin):
                 str(port),
             ]
 
+            if version >= (7, 2):
+                args += [
+                    "--locale-collate",
+                    "C",
+                ]
+
             if password:
                 args += [
                     "--requirepass",
@@ -370,17 +416,25 @@ def start_server(_proc, request, unused_port, server_bin):
                     "--unixsocket",
                     unixsocket,
                 ]
-        f = open(stdout_file, "w")
-        atexit.register(f.close)
-        proc = _proc(
-            *args,
-            shell=False,
-            stdout=f,
-            stderr=subprocess.STDOUT,
-            _clear_tmp_files=tmp_files,
-        )
 
-        with open(stdout_file, "rt") as f_ro:
+        if verbose:
+            print(f"stdout file: {stdout_file}")
+            print("Redis args: " + " ".join(args))
+
+        f = open(stdout_file, "w")
+        # f = open("redis.log", "w")
+        atexit.register(f.close)
+        with open(stdout_file, "r") as f_ro:
+            proc = _proc(
+                *args,
+                shell=False,
+                stdout=f,
+                stderr=subprocess.STDOUT,
+                _clear_tmp_files=tmp_files,
+            )
+
+            redis_is_ready = False
+            slave_is_ready = False
             for _ in timeout(10):
                 if proc.poll() is not None and proc.returncode != 0:
                     f_ro.seek(0)
@@ -390,14 +444,23 @@ def start_server(_proc, request, unused_port, server_bin):
                 log = f_ro.readline()
                 if log and verbose:
                     print(name, ":", log, end="")
-                if "The server is now ready to accept connections " in log:
+                for ready_check_entry in _ready_check_log_entries:
+                    if ready_check_entry in log:
+                        redis_is_ready = True
+                        break
+                if redis_is_ready:
                     break
+
             if slaveof is not None:
                 for _ in timeout(10):
                     log = f_ro.readline()
                     if log and verbose:
                         print(name, ":", log, end="")
-                    if "sync: Finished with success" in log:
+                    for ready_check_entry in _slave_ready_check_log_entries:
+                        if ready_check_entry in log:
+                            slave_is_ready = True
+                            break
+                    if slave_is_ready:
                         break
         info = RedisServer(name, tcp_address, unixsocket, version, password)
         servers.setdefault(name, info)
@@ -456,12 +519,28 @@ def start_sentinel(_proc, request, unused_port, server_bin):
                 write("sentinel failover-timeout", master.name, failover_timeout)
                 write("sentinel auth-pass", master.name, master.password)
 
-        f = open(stdout_file, "w")
-        atexit.register(f.close)
-        proc = _proc(
+        args = [
             server_bin,
             config,
             "--sentinel",
+        ]
+
+        if version >= (7, 2):
+            args += [
+                "--locale-collate",
+                "C",
+            ]
+
+        if verbose:
+            print(f"stdout file: {stdout_file}")
+            print("Redis args: " + " ".join(args))
+
+        # sys.exit(1)
+
+        f = open(stdout_file, "w")
+        atexit.register(f.close)
+        proc = _proc(
+            *args,
             stdout=f,
             stderr=subprocess.STDOUT,
             _clear_tmp_files=tmp_files,
@@ -472,7 +551,7 @@ def start_sentinel(_proc, request, unused_port, server_bin):
             all_slaves = set()
         else:
             all_slaves = {m.name for m in masters}
-        with open(stdout_file, "rt") as f:
+        with open(stdout_file, "r") as f:
             for _ in timeout(30):
                 assert proc.poll() is None, ("Process terminated", proc.returncode)
                 log = f.readline()
@@ -541,7 +620,7 @@ def ssl_proxy(_proc, request, unused_port):
     return sockat
 
 
-@pytest.yield_fixture(scope="session")
+@pytest.fixture(scope="session")
 def _proc():
     processes = []
     tmp_files = set()
@@ -566,39 +645,11 @@ def _proc():
                 pass
 
 
-@pytest.mark.tryfirst
-def pytest_pyfunc_call(pyfuncitem):
-    """
-    Run asyncio marked test functions in an event loop instead of a normal
-    function call.
-    """
-    if inspect.iscoroutinefunction(pyfuncitem.obj):
-        marker = pyfuncitem.get_closest_marker("timeout")
-        if marker is not None and marker.args:
-            timeout = marker.args[0]
-        else:
-            timeout = 15
-
-        funcargs = pyfuncitem.funcargs
-        loop = funcargs["event_loop"]
-        testargs = {arg: funcargs[arg] for arg in pyfuncitem._fixtureinfo.argnames}
-
-        loop.run_until_complete(_wait_coro(pyfuncitem.obj, testargs, timeout=timeout))
-        return True
-
-
 async def _wait_coro(corofunc, kwargs, timeout):
-    async with async_timeout(timeout):
+    async with atimeout(timeout):
         return await corofunc(**kwargs)
 
 
-# def pytest_runtest_setup(item):
-#     is_coro = inspect.iscoroutinefunction(item.obj)
-#     if is_coro and "loop" not in item.fixturenames:
-#         # inject an event loop fixture for all async tests
-#         item.fixturenames.append("loop")
-
-
 def pytest_collection_modifyitems(session, config, items):
     skip_by_version = []
     for item in items:
